﻿// <copyright file="DateTimeAxisDataView.cs" company="Oleg V. Polikarpotchkin">
// Copyright © 2008-2009 Oleg V. Polikarpotchkin. All Right Reserved
// </copyright>
// <author>Oleg V. Polikarpotchkin</author>
// <email>ov-p@yandex.ru</email>
// <date>2009-03-07</date>
// <summary>OpenWPFChart library. DateTime Axis DataView.</summary>
// <revision>$Id: DateTimeAxisDataView.cs 26365 2009-07-29 04:58:40Z unknown $</revision>

using System;
using OpenWPFChart.Parts;

namespace OpenWPFChart.Helpers
{
	/// <summary>
	/// DateTime Axis DataView.
	/// </summary>
	public class DateTimeAxisDataView : AxisDataView
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="DateTimeAxisDataView"/> class.
		/// </summary>
		/// <param name="axis">The DateTimeAxis.</param>
		public DateTimeAxisDataView(DateTimeAxis axis) : base(axis)
		{
		}

		#region TickUnits
		/// <summary>
		/// Gets or sets the TickUnits property.
		/// <para>Tick values are the integer number of DataTime in TickUnits (e.g. "Days").</para>
		/// </summary>
		public DateTimeTickUnits TickUnits
		{
			get { return (AxisScale as ChartDateTimeScale).TickUnits; }
			set
			{
				(AxisScale as ChartDateTimeScale).TickUnits = value;
			}
		}
		#endregion TickUnits

		#region TickStep
		/// <summary>
		/// Gets or sets the TickStep property.
		/// <para>The space between two regular (not long) ticks in DateTimeTickUnits.
		/// It should be positive regardeless of <see cref="Start"/> and <see cref="Stop"/>
		/// values relationship.</para>
		/// </summary>
		/// <value>Any positive long value.</value>
		public long TickStep
		{
			get { return (AxisScale as ChartDateTimeScale).TickStep; }
			set
			{
				(AxisScale as ChartDateTimeScale).TickStep = value;
			}
		}
		#endregion TickStep

		#region LongTickAnchor
		/// <summary>
		/// Gets or sets the LongTickAnchor property.
		/// <para>Represents the position of any long tick.</para>
		/// </summary>
		/// <value>Any finite double value.</value>
		public DateTime LongTickAnchor
		{
			get { return (AxisScale as ChartDateTimeScale).LongTickAnchor; }
			set
			{
				(AxisScale as ChartDateTimeScale).LongTickAnchor = value;
			}
		}
		#endregion LongTickAnchor

		#region LongTickRate
		/// <summary>
		/// Gets or sets the LongTickRate property.
		/// <para>Represents long ticks rate; e.g. 
		/// <list>
		/// if LongTickRate == 1 then all ticks will be long.
		/// if LongTickRate == 2 then will be one short tick between two long ticks.
		/// if LongTickRate == 10 then every tenth tick will be long.
		/// </list>
		/// </para>
		/// </summary>
		/// <value>Positive integer value.</value>
		public int LongTickRate
		{
			get { return (AxisScale as ChartDateTimeScale).LongTickRate; }
			set
			{
				(AxisScale as ChartDateTimeScale).LongTickRate = value;
			}
		}
		#endregion LongTickRate

		#region IDataErrorInfo Members
		protected override string GetDataErrorInfo(string columnName)
		{
			switch (columnName)
			{
				case "TickStep":
					if (TickStep <= 0)
						return "TickStep must be positive";
					return null;
				case "LongTickRate":
					if (LongTickRate <= 0)
						return "LongTickRate must be positive";
					return null;
			}
			return base.GetDataErrorInfo(columnName);
		}
		#endregion IDataErrorInfo Members
	}
}
