﻿// <copyright file="HardcodedCurveData.cs" company="Oleg V. Polikarpotchkin">
// Copyright © 2008 Oleg V. Polikarpotchkin. All Right Reserved
// </copyright>
// <author>Oleg V. Polikarpotchkin</author>
// <email>ov-p@yandex.ru</email>
// <date>2008-12-23</date>
// <summary>OpenWPFChart  library. HardcodedCurveData class contains delegate to get hardcoded function values.</summary>
// <revision>$Id: HardcodedCurveData.cs 22366 2009-04-18 17:11:50Z unknown $</revision>

using System;

namespace OpenWPFChart.Parts
{
	/// <summary>
	/// <see cref="HardcodedCurveData{TAbs, TOrd}"/> class contains <see langword="delegate"/>
	///	to get hardcoded function values.
	/// </summary>
	/// <typeparam name="TX">The type of the abscissas.</typeparam>
	/// <typeparam name="TY">The type of the ordinate.</typeparam>
	public class HardcodedCurveData<TX, TY> : ItemData
	{
		#region Curve
		/// <summary>
		/// Hardcoded function to draw.
		/// </summary>
		public delegate TY CurveDelegate(TX x);

		CurveDelegate curve;
		/// <summary>
		/// Gets or sets the Curve property.
		/// </summary>
		/// <value>The Curve delegate.</value>
		public CurveDelegate Curve
		{
			get { return curve; }
			set
			{
				if (curve != value)
				{
					curve = value;
					NotifyPropertyChanged("Curve");
				}
			}
		}
		#endregion Curve

		/// <inheritdoc />
		public override Type GetDimensionType(int index)
		{
			if (index < 0 || index > 1)
				throw new ArgumentOutOfRangeException("index");
			if (index == 0)
				return typeof(TX);
			else
				return typeof(TY);
		}

		/// <inheritdoc />
		public override bool DimensionEqual(int index, ItemData item)
		{
			return GetDimensionType(index) == item.GetDimensionType(index);
		}
	}
}
