﻿// <copyright file="IPoint3DSeries.cs" company="Oleg V. Polikarpotchkin">
// Copyright © 2008-2009 Oleg V. Polikarpotchkin. All Right Reserved
// </copyright>
// <author>Oleg V. Polikarpotchkin</author>
// <email>ov-p@yandex.ru</email>
// <date>2009-04-18</date>
// <summary>OpenWPFChart library. 3D Point Series generic Interfaces.</summary>
// <revision>$Id: IPoint3DSeries.cs 22500 2009-04-20 15:37:48Z unknown $</revision>

using System;
using System.Collections.Generic;

namespace OpenWPFChart.Parts
{
	/// <summary>
	/// Generic 3D Point.
	/// </summary>
	struct Point3D
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="Point3D"/> struct.
		/// </summary>
		/// <param name="x">The abscissa.</param>
		/// <param name="y">The ordinate.</param>
		/// <param name="z">z-dimension value.</param>
		public Point3D(object x, object y, object z)
			: this()
		{
			X = x;
			Y = y;
			Z = z;
		}

		/// <summary>
		/// Gets the abscissa.
		/// </summary>
		/// <value>The abscissa.</value>
		public object X { get; private set; }

		/// <summary>
		/// Gets the ordinate.
		/// </summary>
		/// <value>The ordinate.</value>
		public object Y { get; private set; }

		/// <summary>
		/// Gets the z-dimension value.
		/// </summary>
		/// <value>z-dimension value.</value>
		public object Z { get; private set; }

		#region object overrides
		/// <summary>
		/// Indicates whether this instance and a specified object are equal.
		/// </summary>
		/// <param name="obj">Another object to compare to.</param>
		/// <returns>
		/// true if <paramref name="obj"/> and this instance are the same type and represent the same value; otherwise, false.
		/// </returns>
		public override bool Equals(object obj)
		{
			if (obj == null || obj.GetType() != typeof(Point3D))
				return false;
			Point3D pt = (Point3D)obj;
			return (X.Equals(pt.X) && Y.Equals(pt.Y) && Z.Equals(pt.Z));
		}

		/// <summary>
		/// Returns the hash code for this instance.
		/// </summary>
		/// <returns>
		/// A 32-bit signed integer that is the hash code for this instance.
		/// </returns>
		public override int GetHashCode()
		{
			return (X.GetHashCode() ^ Y.GetHashCode() ^ Z.GetHashCode());
		}

		/// <summary>
		/// Returns this instance string representation.
		/// </summary>
		/// <returns>this instance <see cref="T:System.String"/> representation.</returns>
		public override string ToString()
		{
			return string.Format("({0},{1},{2})", X, Y, Z);
		}
		#endregion object overrides
	}

	/// <summary>
	/// 3D Data Point Series Interface.
	/// </summary>
	interface IPoint3DSeries
	{
		/// <summary>
		/// Gets the generic 3D Point.
		/// </summary>
		/// <value>3D points.</value>
		IEnumerable<Point3D> Points { get; }
	}
}
