﻿// <copyright file="ItemVisual.cs" company="Oleg V. Polikarpotchkin">
// Copyright © 2008 Oleg V. Polikarpotchkin. All Right Reserved
// </copyright>
// <author>Oleg V. Polikarpotchkin</author>
// <email>ov-p@yandex.ru</email>
// <date>2008-12-23</date>
// <summary>OpenWPFChart library. Item's Visuals abstract base class.</summary>
// <revision>$Id: ItemVisual.cs 24435 2009-05-27 04:36:34Z unknown $</revision>

using System.Diagnostics;
using System.Windows;
using System.Windows.Media;

namespace OpenWPFChart.Parts
{
	/// <summary>
	/// Item's Visuals abstract base class.
	/// </summary>
	public abstract class ItemVisual : DrawingVisual
	{
		#region DataView
		/// <summary>
		/// Identifies the DataView dependency property.
		/// </summary>
		public static readonly DependencyProperty DataViewProperty
			= Item.DataViewProperty.AddOwner(typeof(ItemVisual));
		/// <summary>
		/// Gets or sets the DataView property.
		/// </summary>
		/// <value>DataView object.</value>
		public DataView DataView
		{
			get { return (DataView)GetValue(DataViewProperty); }
			set { SetValue(DataViewProperty, value); }
		}
		#endregion DataView

		/// <summary>
		/// Render Curve Visual.
		/// </summary>
		protected internal abstract void Render();

		/// <summary>
		/// Checks the 'pt' is inside the area. All coordinates come in pixels.
		/// </summary>
		/// <param name="pt">The pt.</param>
		/// <param name="area">The area.</param>
		/// <returns>
		/// 	<c>true</c> if the specified pt is inside the area; otherwise, <c>false</c>.
		/// </returns>
		protected static bool isInsideArea(Point pt, Size area)
		{
			Debug.Assert(area.Width >= 0, "area.Width >= 0");
			Debug.Assert(area.Height >= 0, "area.Height >= 0");
			if (pt.X < 0 || pt.X > area.Width || pt.Y < 0 || pt.Y > area.Height)
				return false;
			return true;
		}
	}
}
