﻿// <copyright file="XmlItemDataReaderSchemaBuilderTest.cs" company="Oleg V. Polikarpotchkin">
// Copyright © 2008-2009 Oleg V. Polikarpotchkin. All Right Reserved
// </copyright>
// <author>Oleg V. Polikarpotchkin</author>
// <email>ov-p@yandex.ru</email>
// <date>2009-04-12</date>
// <summary>WPF OpenWPFChart library. Helpers.XmlItemDataReader.SchemaBuilder class Test.</summary>
// <revision>$Id: XmlItemDataReaderSchemaBuilderTest.cs 22222 2009-04-17 05:06:31Z unknown $</revision>

using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Xml.Schema;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpenWPFChart.Helpers.XmlItemDataReader;

namespace Tests
{
    /// <summary>
	/// This is a test class for <see cref="OpenWPFChart.Helpers.XmlItemDataReader.SchemaBuilder"/>
	/// class and is intended to contain all SchemaBuilderTest Unit Tests
    ///</summary>
	[TestClass()]
	public class XmlItemDataReaderSchemaBuilderTest
	{
		#region TestContext
		private TestContext testContextInstance;

		/// <summary>
		///Gets or sets the test context which provides
		///information about and functionality for the current test run.
		///</summary>
		public TestContext TestContext
		{
			get
			{
				return testContextInstance;
			}
			set
			{
				testContextInstance = value;
			}
		}
		#endregion TestContext

		#region Additional test attributes
		// 
		//You can use the following additional attributes as you write your tests:
		//
		//Use ClassInitialize to run code before running the first test in the class
		//[ClassInitialize()]
		//public static void MyClassInitialize(TestContext testContext)
		//{
		//}
		//
		//Use ClassCleanup to run code after all tests in a class have run
		//[ClassCleanup()]
		//public static void MyClassCleanup()
		//{
		//}
		//
		//Use TestInitialize to run code before running each test
		//[TestInitialize()]
		//public void MyTestInitialize()
		//{
		//}
		//
		//Use TestCleanup to run code after each test has run
		//[TestCleanup()]
		//public void MyTestCleanup()
		//{
		//}
		//
		#endregion

		/// <summary>
		///A test for Build
		///</summary>
		[TestMethod()]
		public void BuildTest()
		{
			string xmlMappings = @"<?xml version='1.0' encoding='utf-8'?>
			<Mappings xmlns='urn:ItemData-mapping'>
				<Mapping>
					<XAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
					<YAxis xsd-type='int' clr-type='System.Int32' type-string='Int'/>
				</Mapping>
				<Mapping>
					<XAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
					<YAxis xsd-type='double' clr-type='System.Double' type-string='Double'/>
				</Mapping>
				<Mapping>
					<XAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
					<YAxis xsd-type='dateTime' clr-type='System.DateTime' type-string='DateTime'/>
				</Mapping>
				<Mapping>
					<XAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
					<YAxis xsd-type='date' clr-type='System.DateTime' type-string='Date'/>
				</Mapping>
				<Mapping>
					<XAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
					<YAxis xsd-type='gMonth' clr-type='System.Int32' type-string='Month'/>
				</Mapping>
			</Mappings>";

			using (StringReader sr = new StringReader(xmlMappings))
			{
				List<Mapping> mappings = Mapping.Load(sr);
				Assert.IsNotNull(mappings);
				Assert.AreEqual(5, mappings.Count());

				XmlSchemaSet schemaSet = SchemaBuilder.Build(mappings);
				Assert.IsNotNull(schemaSet);
			}
		}
	}
}
